/******************************************************************************/
//
// Name: 	Programming S/PDIF on ADSP-21369 SHARC(R) DSP Processor
//
/******************************************************************************

(C) Copyright 2005 - Analog Devices, Inc.  All rights reserved.

File Name:		main.c

Date Modified:	21/03/05	-	AV	-	Rev 1.0

Software:       VisualDSP++3.5 (November update)

Purpose:		To demonstrate S/PDIF programming - Talk-through example
				
*******************************************************************************/

//Include header files
#include <stdio.h>
#include <Cdef21369.h>
#include <def21369.h>
#include <signal.h>

//#defines
#define CLKA_DIVIDER 8 //--provides SCLK serial clock to S/PDIF TX and SPORT0
#define FSA_DIVIDER 512//--provides Frame Sync to S/PDIF TX and SPORT0
#define CLKB_DIVIDER 2 //--provides HFCLK to S/PDIF TX

//Global function declarations
void InitPCGA_B(void);
void InitSRU(void);
void SPDIF_TX_Init(void);
void SPDIF_RX_Init(void);
void Sport1Init(void);
void Sport0Init(void);
void Sport1RxIsr(int dummy);
void Sport0TxIsr(int dummy);

//Global variable declarations
unsigned int RX_VALUE = 0;
unsigned int TMP_RX_VALUE;

void main(void)
{
	interrupts(SIG_P3,Sport1RxIsr);//--set up sport1 interrupt
	
	InitPCGA_B();
	InitSRU();
	Sport1Init();
	Sport0Init();
	SPDIF_TX_Init();
	
	while(1)
	{
	}
	
}


void Sport1RxIsr(int dummy)
{
	
	RX_VALUE = *pRXSP1A;
	*pTXSP0A = RX_VALUE;
	
}


//Initialize SPDIF Transmitter
void SPDIF_TX_Init()
{
	*pDITCTL = DIT_EN | DIT_SMODEIN0;//configuration of SPDIF TX
}
//-------------------------------------------------------------


void SPDIF_RX_Init()
{
	//SPDIF_RX control register configuration done here if needed.
}


//Initialize SPORT1
void Sport1Init()
{
	*pSPCTL1 |= SPEN_A | SLEN32 | OPMODE ;				//SPORT1 configuration:
														//External clock and word select 
														//I2S mode
														//Receiver
														//Word length 32
}

//Initialize SPORT0
void Sport0Init()
{
	*pSPCTL0 |= SPEN_A | SLEN32 | OPMODE | SPTRAN ;		//SPORT0 configuration:
														//External clock and word select 
														//I2S mode
														//Transmitter
														//Word length 32
}

//-- PCG "A" and "B" configuration
void InitPCGA_B()
{
	*pPCG_CTLA1 = CLKA_DIVIDER | 0xC00000; //--allign FS rising with CLK falling from PCG for I2S mode
	*pPCG_CTLA0 = FSA_DIVIDER | ENFSA | ENCLKA ; 
	
	*pPCG_CTLB1 = CLKB_DIVIDER; 
	*pPCG_CTLB0 = ENCLKB ;

	*pPCG_PW = 0;
	*pPCG_SYNC = 0;		
}

